@@ -9,7 +9,7 @@ import shutil
 
 
 # will return the content of a directory (full paths)
-def get_dir_content(dir_path, recursive=False, collect_dirs=True, collect_files=True, ignored_files_arr=['.DS_Store']):
+def get_dir_content(dir_path, recursive=False, collect_dirs=True, collect_files=True, ignored_files_arr=['.DS_Store'], sort_by_name=True):
     f_list = []
     d_list = []
     for path, dirs, files in os.walk(dir_path):
@@ -29,7 +29,11 @@ def get_dir_content(dir_path, recursive=False, collect_dirs=True, collect_files=
 
     f_list = list(filter(lambda x: get_file_name_from_path(x) not in ignored_files_arr, f_list))
     if f_list:
+        if sort_by_name:
+            f_list.sort()
         if d_list:
+            if sort_by_name:
+                d_list.sort()
             return [d_list, f_list]
         return f_list
     return d_list
